pub struct SocketFileInfo {
pub socket_id: usize,
}Expand description
Information about socket files in the filesystem
Scarlet uses socket IDs to uniquely identify socket objects in the NetworkManager. This allows socket files to be created in the filesystem and associated with actual socket objects for inter-process communication.
Architecture
Similar to device files, socket files in Scarlet are identified by:
socket_id: A unique identifier within the NetworkManager’s socket registry
This enables Unix domain socket-like functionality where sockets can be bound to filesystem paths for inter-process communication.
Examples
// Socket file for IPC
let socket_file = SocketFileInfo {
socket_id: 42,
};Fields
socket_id: usizeTrait Implementations
Sourceimpl Clone for SocketFileInfo
impl Clone for SocketFileInfo
Sourcefn clone(&self) -> SocketFileInfo
fn clone(&self) -> SocketFileInfo
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SocketFileInfo
impl Debug for SocketFileInfo
Sourceimpl PartialEq for SocketFileInfo
impl PartialEq for SocketFileInfo
impl Copy for SocketFileInfo
impl StructuralPartialEq for SocketFileInfo